import {HamburgerIcon, Pressable, Menu, Text, Icon, ChevronRightIcon, HStack, VStack} from "native-base"
import {useRoute} from "@react-navigation/native"
import {Dimensions} from "react-native"
import React from "react"
import {AntDesign} from "@expo/vector-icons"

type MenuComponentProps = {
    navigation: any
}

const screenWidth = Dimensions.get('window').width; // Get full screen width


const MenuComponent = (props: MenuComponentProps) => {
    const route = useRoute().name

    return (
        <>
            <Menu w={screenWidth} mt={2} shadow={"0"} color={"primary.500"} backgroundColor={"white"} trigger={ triggerProps => {
                return <Pressable accessibilityLabel="More options menu" { ...triggerProps }>
                    <HamburgerIcon color={"primary.500"} size={"lg"}/>
                </Pressable>

            } }>
                <VStack width={"full"} >
                    <Menu.Item
                        onPress={ () => props.navigation.navigate("Home") }
                        _text={ { color: "primary.500" } }
                        _pressed={ { bg: "secondary.500" } }
                        bg={ route === "Home" ? "secondary.500" : "white" }
                        rounded={"3xl"}
                        mx={5}
                    >
                        <HStack  justifyContent="space-between" alignItems="center" w="100%">
                            <HStack alignItems="center" space={2}>
                                <Icon as={<AntDesign name="home"  />} color="primary.500" size={"lg"} />
                                <Text fontSize={"lg"} color={"primary.500"} fontWeight={"bold"}>Home</Text>
                            </HStack>
                            <ChevronRightIcon color="primary.500" />
                        </HStack>
                    </Menu.Item>
                    <Menu.Item
                        onPress={ () => props.navigation.navigate("Notes") }
                        _text={ { color: "primary.500" } }
                        _pressed={ { bg: "secondary.500" } }
                        bg={ route === "Notes" ? "secondary.500" : "white" }
                        rounded={"3xl"}
                        mx={5}
                    >
                        <HStack justifyContent="space-between" alignItems="center" w="100%">
                            <HStack alignItems="center" space={2}>
                                <Icon as={<AntDesign name="profile" />} color="primary.500" size={"lg"}/>
                                <Text fontSize={"lg"} color={"primary.500"} fontWeight={"bold"}>Notes</Text>
                            </HStack>
                            <ChevronRightIcon color="primary.500" />
                        </HStack>
                    </Menu.Item>
                    <Menu.Item
                        onPress={ () => props.navigation.navigate("Search", { inventoryId: null }) }
                        _text={ { color: "primary.500" } }
                        _pressed={ { bg: "secondary.500" } }
                        bg={ route === "Search" ? "secondary.500" : "white" }
                        rounded={"3xl"}
                        mx={5}
                    >
                        <HStack justifyContent="space-between" alignItems="center" w="100%">
                            <HStack alignItems="center" space={2}>
                                <Icon as={<AntDesign name="search1"  />} color="primary.500" size={"lg"}/>
                                <Text fontSize={"lg"} color={"primary.500"} fontWeight={"bold"}>Search</Text>
                            </HStack>
                            <ChevronRightIcon color="primary.500" />
                        </HStack>
                    </Menu.Item>
                    <Menu.Item
                        onPress={ () => props.navigation.navigate("Plan", { placeId: undefined, roomId: undefined }) }
                        _text={ { color: "primary.500" } }
                        _pressed={ { bg: "secondary.500" } }
                        bg={ route === "Plan" ? "secondary.500" : "white" }
                        rounded={"3xl"}
                        mx={5}
                    >
                        <HStack rounded={"lg"} justifyContent="space-between" alignItems="center" w="100%">
                            <HStack alignItems="center" space={2}>
                                <Icon as={<AntDesign name="appstore-o" />} color="primary.500" size={"lg"} />
                                <Text fontSize={"lg"} color={"primary.500"} fontWeight={"bold"}>Plan</Text>
                            </HStack>
                            <ChevronRightIcon color="primary.500" />
                        </HStack>
                    </Menu.Item>
                    <Menu.Item
                        onPress={ () => props.navigation.navigate("Logout") }
                        _text={ { color: "primary.500" } }
                        _pressed={ { bg: "secondary.500" } }
                        rounded={"3xl"}
                        mx={5}
                    >
                        <HStack justifyContent="space-between" alignItems="center" w="100%">
                            <HStack alignItems="center" space={2}>
                                <Icon as={<AntDesign name="logout" />} color="primary.500" size={"lg"} />
                                <Text fontSize={"lg"} color={"primary.500"} fontWeight={"bold"}>Logout</Text>
                            </HStack>
                            <ChevronRightIcon color="primary.500" />
                        </HStack>
                    </Menu.Item>
                </VStack>

            </Menu>
        </>
    )
}

export default MenuComponent
